@@ -6,10 +6,10 @@
 # modify it under the terms of the MIT License; see LICENSE file for more
 # details.
 
-"""This package serves as a place for the workflows of the repository of the TU Graz."""
+"""Package serves as a place for the workflows of the repository of the TU Graz."""
 
 from .ext import InvenioWorkflowsTugraz
 
-__version__ = "0.1.6"
+__version__ = "0.2.1"
 
 __all__ = ("__version__", "InvenioWorkflowsTugraz")
