@@ -13,6 +13,8 @@ fixtures are available.
 """
 
 
+from collections.abc import Callable
+
 import pytest
 from flask import Flask
 
@@ -20,19 +22,10 @@ from invenio_workflows_tugraz import InvenioWorkflowsTugraz
 
 
 @pytest.fixture(scope="module")
-def celery_config():
-    """Override pytest-invenio fixture.
-
-    TODO: Remove this fixture if you add Celery support.
-    """
-    return {}
-
-
-@pytest.fixture(scope="module")
-def create_app(instance_path):
+def create_app(instance_path: str) -> Callable:
     """Application factory fixture."""
 
-    def factory(**config):
+    def factory(**config: dict) -> Flask:
         app = Flask("testapp", instance_path=instance_path)
         app.config.update(**config)
         InvenioWorkflowsTugraz(app)
